#
# spec file for package cpuset
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2008-2011 Novell, Inc. Waltham, MA, USA
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif
Name:           cpuset
Version:        1.6.2
Release:        1.3
Summary:        Cpuset manipulation tool
License:        GPL-2.0-only
Group:          System/Management
URL:            https://github.com/SUSE/cpuset
Source:         https://github.com/SUSE/cpuset/archive/refs/tags/v%{version}.tar.gz
BuildRequires:  python3-setuptools

%description
Cpuset is a Python application for using the cpuset facilities in
the Linux kernel. The actual included command is called cset
and allows manipulation of cpusets on the system, and provides higher
level functions such as implementation and control of a basic CPU
shielding setup.

%prep
%setup -q
%autopatch -p1

%build
python3 setup.py build
#make doc  ->not yet, asciidoc is missing...

%install
# Install binaries, but do not install docs via setup.py
python3 setup.py install --root=%{buildroot} --prefix=%{_prefix} --install-data=/eraseme
rm -rf %{buildroot}/eraseme

# Install documentation
mkdir -p %{buildroot}/%{_mandir}/man1
mkdir -p %{buildroot}/%{_defaultdocdir}/%{name}/html

install -m 0444 doc/*.1 %{buildroot}/%{_mandir}/man1

install -m 0444 NEWS README AUTHORS cset.init.d doc/*.txt %{buildroot}/%{_defaultdocdir}/%{name}
install -m 0444 doc/*.html %{buildroot}/%{_defaultdocdir}/%{name}/html/

%files
%license COPYING
%doc %{_docdir}/%{name}
%{_bindir}/cset
%{python3_sitelib}/*
%{_mandir}/man1/*

%changelog
* Tue Nov 21 2023 Michal Koutný <mkoutny@suse.com>
- Update to 4f80263, release v1.6.2
  * Update descriptor to match any python 3.x version
  * Remove python2.x specific paths in the spec file after #33 got merged
  * Update the github project location to github.com/SUSE/cpuset
  * Remove Python 2 support
  * cpuset.spec: Update source URL
* Wed Aug  2 2023 Michal Koutný <mkoutny@suse.com>
- Update to 394c8b0, release v1.6.1
  * Fix --syset typo (bsc#1210468)
  * fix doc typo (bsc#1210468)
- Remove cpuset-1.6-Fix_invalid_parentheses.patch: in upstream tarball
* Fri Nov 12 2021 Libor Pechacek <lpechacek@suse.com>
- Add cpuset-1.6-Fix_invalid_parentheses.patch to fix
  a semantic error. (bsc#1191418)
* Tue Dec 11 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Dec 11 2018 lpechacek@suse.com
- Update to 6c46d71a1c6e, release v1.6
* Tue Mar 27 2018 tchvatal@suse.com
- Do not require -devel but use only setuptools module
- Use ~ in version as without it the package is newer than
  release 1.6
- Reduce the compat py2/py3 choicer, SLE12 can be python3
* Thu Feb  8 2018 lpechacek@suse.com
- Update to 02ef9e09e1da, release v1.6pre1 (bsc#1079868)
* Fri Mar 24 2017 lpechacek@suse.com
- Fix SLE 11 build in Devel project
* Thu Mar  9 2017 sfalken@opensuse.org
- Edited %%files to clear unpackaged files builderror in
  openSUSE:Factory
* Wed Jan 13 2016 idonmez@suse.com
- Cleanup spec file
- Use source url
* Wed Jan 13 2016 lpechacek@suse.com
- Update to ae629aa1dc95, release 1.5.7
- Deleted patches:
  Docu-fix-asciidoc-build-error.patch
  Docu-fixed-a-typo.patch
  Docu-remove-mention-about-nonexistent-option.patch
  Fix-crash-with-SCHED_IDLE-policy.patch
  Fix-typo-in-setup-py.patch
  Handle-unknown-scheduler-policy-codes-gracefully.patch
  Parse-proc-pid-stat-properly.patch
  Update-URLs-after-project-migration.patch
  cset-make-it-handle-cgroup-mounts.patch
* Wed Dec 30 2015 mgalbraith@suse.com
- Remove obsolete 'Authors' section from cpuset.spec.
* Tue Dec 29 2015 mgalbraith@suse.com
- Merge new cpuset upstream.  Update URL, and add post v1.5.6 fixes.
- New patches:
  Fix-crash-with-SCHED_IDLE-policy.patch (bnc#959992)
  Handle-unknown-scheduler-policy-codes-gracefully.patch (bnc#959992)
  Parse-proc-pid-stat-properly.patch
  Docu-remove-mention-about-nonexistent-option.patch (bnc#957323)
  Docu-fix-asciidoc-build-error.patch
  Update-URLs-after-project-migration.patch
  Docu-fixed-a-typo.patch
  Fix-typo-in-setup-py.patch
* Wed May 28 2014 mgalbraith@suse.com
- Explicitly state that the previous commit..
  "Make cset handle cgroup/cpuset mount types"
  ..added patch cset-make-it-handle-cgroup-mounts.patch
* Tue May 27 2014 mgalbraith@suse.com
- Make cset handle cgroup/cpuset mount types (SUSE bnc#625079, SUSE bnc#834223)
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Thu Jun  9 2011 Alex Tsariounov <alext@novell.com>
- Update to hg 33:74eb810ae9d9, release 1.5.6
- Fix Issue#5: LOGNAME not set wnen exec with --user arg
* Tue Aug  3 2010 Alex Tsariounov <alext@novell.com>
- Update to hg 28:a73efd0e8871, release 1.5.5
- Fix Issue#3: cset fails to create cpu sets if some cpus are offline
* Fri May  7 2010 Alex Tsariounov <alext@novell.com>
- Update to hg 23:c6e5393187b2, release 1.5.4
- Fix exception when running tasks with non-existent uids
* Thu Feb 11 2010 Alex Tsariounov <alext@novell.com>
- Update to hg 18:e50c7714a80d, release 1.5.3
- Fix failure of finding cpusets in a case-sensitive manner
- Code repository and hosting moved to http://code.google.com/p/cpuset
- Updated dates and details
* Mon Nov 30 2009 Alex Tsariounov <alext@novell.com>
- Update to svn 251, release 1.5.2
- Fix bug bnc#558395: cset couldn't delete cpu set
- Fix bug bnc#558399 - cset unable to move thread
- Fixed failure to delete cpuset if removed tasks stil
  preset since they can be tardy to leave
- Quiet down not found and unmovable task output
- Add example init.d cset file in documentation directory
* Wed Jun 17 2009 Alex Tsariounov <alext@novell.com>
- Update to svn 226, release 1.5.1
- Fix bug #26: Cpuset does not function on machines with greater than 16 CPUs
* Sun Feb  8 2009 alext@suse.de
- Update to svn 221, release 1.5.0
- Fix bug #1: Origination cpuset not accepted for process move...
- Fix bug #2: Proc move from set to set does not recognize...
- Fix bug #3: Interspersed arguments do not work
- Fix bug #4: Add policy and priority to proc output list
- Fix bug #5: Add ability to move all threads in a process container wi.
- Fix bug #6: The -a option for set listing should be the default
- Fix bug #7: Add destination cpuset for the proc move command
- Fix bug #8: Let leading slash for nested cpuset spec be optional
- Fix bug #9: Rearrange info output some, include machine readable output
- Fix bug #10: Add a recursive cpuset delete with option
- Fix bug #11: Add a configuration file
- Fix bug #12: Add hex mask output for cpuset definition spec (cpuspec)
- Fix bug #13: Add cpuset rename option to set command
- Fix bug #21: Create shield shortcuts
- Changed behavior of shield command, now it behaves more like the proc move
  command: -s or -u needs a -p to shield or unshield, however, the shortcut of
  shield pidspec still works.
- Fixed exception when using cset with pipes
- Fixed set list behavior if --set was specified but not --list
- Added error message if proc list command does not specify a set
- Fixed exception if proc is used with -l and -s
- Location for cpuset filesystem mount can be specified in config file
- Changed proc option -a/--all to --force only
- Updated copyrights, URLs and documentation
- Added spec file to svn which is used in build service
- Cleaned up status output for clarity and consistency
- Additional minor corner case bug fixes included
* Thu Dec  4 2008 alext@suse.de
- Updated spec file to build on many distros
* Tue Sep  2 2008 alext@suse.de
- Update to svn version 135, release 1.04
- Fixes bnc#422324 - Cset tool fails when cpu offlined
* Fri Jul 18 2008 alext@suse.de
- Update to svn version 133, release 1.03
- Remove class variable CpuSet.sets dictionary when CpuSet object
  (re)initialized.  If you use cset as a library, then since the
  class var did not get zeroed out, old sets were found on
  cset.rescan() which broke the data structure.
- Fixes bnc#410636
* Tue Jun 10 2008 alext@suse.de
- Update to svn version 126, release 1.02
- Fix bug in new cpuset mount detection code
* Tue Jun 10 2008 alext@suse.de
- Update to svn version 122, release 1.01
- Fix community reported bug of not seeing cpuset filesystem
  mounted if running control groups (cgroups)
- Remove need to mount cpuset filesystem if only executing help
- Fix traceback if giving list of sets to list procs command
* Fri May 30 2008 alext@suse.de
- Update to svn version 117, release 1.0
- Addition of man pages and html docs
* Fri May  9 2008 alext@suse.de
- Update to svn revision 104, release 0.9.1
- Fix bug #388958
- Add files README and COPYING to rpm
* Fri May  2 2008 alext@suse.de
- Update to svn version 102, release 0.9
- Added -k/--kthread to proc move command to move kernel threads
- Kernel threads are not moved automatically for generic move
  unless -k is also used
- If kernel threads are not unbound, then both -k and -a is
  necessary
- Improved information output for why tasks are moved or not
- FYI: previous release 0.8 was svn revision 96
* Wed Apr 23 2008 alext@suse.de
- Fixed bug #380819
- Fixed incorrect test for unbound task for shield; affects
  kernel thread shielding
- Change proc -l to always output long listing of tasks in
  specified cpuset since set -l will output summary
- Removed text re recommending 2.6.22
- Added correct source url
- Added check for existing subsets for set --delete command
- Switched to Novell Outerforge for svn:
  http://developer.novell.com/wiki/index.php/Cpuset
* Thu Apr  3 2008 alext@suse.de
- Update to svn version 143, release 0.7
- First fully functional release: commands shield, set and proc
  work.
- Updated online docs.
- Known issues:
-  irq threads not moved for -kon for shield command
-  odd messages output from OS when incorrect cpusets commands
  issued
-  missing documentation: man pages and tutorial
* Thu Mar 20 2008 alext@suse.de
- Update to svn version 127, release 0.6
- Added --user/--group for exec options for the shield and proc
  commands.  Cset still needs to be root in order to manipulate
  cpusets, but you can exec other processes as different users.
- Removed explicit check for root uid.  Now all permissions checks
  are implicit.
- Changed proc/--run to proc/--exec to match shield.
- Shield/unshield commands now only move tasks from unshield to shield
  or shield to unshield, and leave tasks in the root cpuset alone,
  unless the --force option is specified.
- Added clearer output feedback.
* Tue Mar 18 2008 alext@suse.de
- Update to svn version 116, release 0.5
- Fixes to cset/proc command for moving tasks.
- More cset/set code, but set still not 100%%.
* Fri Mar 14 2008 alext@suse.de
- Update to svn version 109, release 0.4
- The proc command is fully functional. The set command has
  documentation and revised options. The mem command has been
  removed.
* Wed Mar 12 2008 alext@suse.de
- Update to svn version 89, release 0.3
- Incorporate feedback for shield supercommand from initial 0.2
  release.
* Sat Feb 16 2008 alext@suse.de
- Update to version 0.2, svn version 77.
- The shield supercommand is fully functional.  Other commands are
  not yet implemented.
* Thu Jan 24 2008 alext@suse.de
- Remove error in abuild for including generic doc directory in
  list of files
* Thu Jan 24 2008 alext@suse.de
- Changed --record to --record-rpm to fix build.
* Wed Jan 16 2008 alext@suse.de
- Initial submission to autobuild, pdb entry exists.
- Currently not functional, version set to 0.1.
